@@ -19,7 +19,7 @@
 
 package FindBin::libs;
 
-use v5.10;
+use v5.14;
 use strict;
 
 use FindBin;
@@ -75,7 +75,7 @@ BEGIN
 # package variables 
 ########################################################################
 
-our $VERSION    = '2.10';
+our $VERSION    = '2.12';
 $VERSION = eval $VERSION;
 
 my %defaultz = 
@@ -203,6 +203,9 @@ my $find_libs
     # (including volume) walking up the path 
     # from $FindBin::Bin -> root.
     #
+    # no libs found is empty list or undef for 
+    # scalar.
+    #
     # passing it back as a list isn't all that
     # painful for a few paths.
 
@@ -352,6 +355,10 @@ sub import
 
     if( $argz{ export } )
     {
+        # this has to run in order to install variables that
+        # the caller is expecting to exist at runtime -- even
+        # if they are empty/undef at the end of it.
+
         my $ref     = qualify_to_ref $argz{ export }, $caller;
 
         if( $verbose )
@@ -366,7 +373,11 @@ sub import
 
         if( $argz{ scalar } )
         {
-            *$ref = \$libz[0]
+            *$ref 
+            = @libz
+            ? \$libz[0]
+            : \( my $a = '' )
+            ;
         }
         elsif
         (
@@ -383,28 +394,34 @@ sub import
         }
     }
 
-    if( defined $argz{ p5lib } )
+    # no 'else', these are not exclusive
+
+    if( @libz )
     {
-        # stuff the lib's found at the front of $ENV{ PERL5LIB }
+        if( defined $argz{ p5lib } )
+        {
+            # stuff the lib's found at the front of $ENV{ PERL5LIB }
+            # yes, virginia, substr is an lvalue -- and saner than
+            # dealing with \Q and a regex on arbitrary paths.
 
-        ( substr $ENV{ PERL5LIB }, 0, 0 ) = join ':', @libz, ''
-        if @libz;
+            ( substr $ENV{ PERL5LIB }, 0, 0 ) = join ':', @libz, '';
 
-        print STDERR "\nUpdated PERL5LIB:\t$ENV{ PERL5LIB }\n"
-        if $verbose;
-    }
+            print STDERR "\nUpdated PERL5LIB:\t$ENV{ PERL5LIB }\n"
+            if $verbose;
+        }
 
-    if( $argz{ use } && @libz )
-    {
-        # this obviously won't work if lib ever depends 
-        # on the caller's package.
-        #
-        # it does avoids issues with -T blowing up on the
-        # old eval technique.
+        if( $argz{ use } )
+        {
+            # this obviously won't work if lib ever depends 
+            # on the caller's package.
+            #
+            # it does avoids issues with -T blowing up on the
+            # old eval technique.
 
-        require lib;
+            require lib;
 
-        lib->import( @libz );
+            lib->import( @libz );
+        }
     }
 
     0
@@ -637,7 +654,7 @@ produces something like
     )
 
 without append @etc will have only ./bar/etc since the array would
-be overwritten with each call to FB::l::import.
+be overwritten with each call to import.
 
 =back
 
